@@ -56,7 +56,8 @@ tar_format_alias <- function(format) {
       resources = resources,
       storage = storage,
       retrieval = retrieval,
-      cue = cue
+      cue = cue,
+      description = description
     )
   }, env = list(format = format))
   out
@@ -79,7 +80,8 @@ tar_format_api <- function(
   resources = targets::tar_option_get("resources"),
   storage = targets::tar_option_get("storage"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
 }
 
