@@ -56,6 +56,7 @@ tar_map_rep <- function(
   command,
   values = NULL,
   names = NULL,
+  descriptions = tidyselect::everything(),
   columns = tidyselect::everything(),
   batches = 1,
   reps = 1,
@@ -74,13 +75,15 @@ tar_map_rep <- function(
   resources = targets::tar_option_get("resources"),
   storage = targets::tar_option_get("storage"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
   tar_map_rep_raw(
     name = deparse(substitute(name)),
     command = substitute(command),
     values = values,
     names = substitute(names),
+    descriptions = substitute(descriptions),
     columns = substitute(columns),
     batches = batches,
     reps = reps,
@@ -99,6 +102,7 @@ tar_map_rep <- function(
     resources = resources,
     storage = storage,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
 }
