@@ -95,6 +95,7 @@
 tar_quarto_rep <- function(
   name,
   path,
+  working_directory = NULL,
   execute_params = data.frame(),
   batches = NULL,
   extra_files = character(0),
@@ -103,6 +104,7 @@ tar_quarto_rep <- function(
   cache_refresh = FALSE,
   debug = FALSE,
   quiet = TRUE,
+  quarto_args = NULL,
   pandoc_args = NULL,
   rep_workers = 1,
   tidy_eval = targets::tar_option_get("tidy_eval"),
@@ -117,7 +119,8 @@ tar_quarto_rep <- function(
   priority = targets::tar_option_get("priority"),
   resources = targets::tar_option_get("resources"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
   execute_params <- targets::tar_tidy_eval(
     substitute(execute_params),
@@ -127,6 +130,7 @@ tar_quarto_rep <- function(
   tar_quarto_rep_raw(
     name = targets::tar_deparse_language(substitute(name)),
     path = path,
+    working_directory = working_directory,
     execute_params = execute_params,
     batches = batches,
     extra_files = extra_files,
@@ -135,6 +139,7 @@ tar_quarto_rep <- function(
     cache_refresh = cache_refresh,
     debug = debug,
     quiet = quiet,
+    quarto_args = quarto_args,
     pandoc_args = pandoc_args,
     rep_workers = rep_workers,
     packages = packages,
@@ -148,6 +153,7 @@ tar_quarto_rep <- function(
     priority = priority,
     resources = resources,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
 }
